from .stingray_base import StingrayBase


class StingrayToken(StingrayBase):
    """
    Class for interact with Stingray system through ci/cd token
    """

    def __init__(self, base_url, ci_token, company_id):
        super().__init__(base_url)
        self.company_id = company_id
        self.current_context = {"company": company_id}
        self.headers = {'Authorization': 'Token {0}'.format(ci_token),
                        'Content-Type': 'application/json'}

    def set_headers(self, ci_token):
        self.headers = {'Authorization': 'Token {0}'.format(ci_token)}



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="stingray_cli_core",
    version='2.1.4',
    author="Stingray Technologies LLC",
    description="Stingray core package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Swordfish-Security/stingray-cli-core",
    packages=find_packages(),
    author_email='stingray@appsec.global',
    include_package_data=True,
    install_requires=[
         'requests'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Unix",
    ],
)
